@@ -1,28 +1,33 @@
 from Acquisition import aq_inner
 from Products.CMFCore.utils import getToolByName
-from Products.Five.browser import BrowserView
+from zope.cachedescriptors.property import Lazy
 from plone.memoize.view import memoize
 from zope.component import getMultiAdapter
+try:
+    import xm.theme
+except ImportError:
+    HAS_XM_THEME = False
+else:
+    HAS_XM_THEME = True
+
 
 from Products.eXtremeManagement.browser.xmbase import XMBaseView
 from Products.eXtremeManagement.utils import formatTime
 
 
-class MyProjects(BrowserView):
+class MyProjects(XMBaseView):
     """Return the projects that I have tasks in.
     """
     request = None
     context = None
-    states = ('open', 'to-do')
-    # Use state = '' if you do not want to filter for states.
 
     @property
     @memoize
     def projectlist(self):
         context = aq_inner(self.context)
         # Get a list of all projects
-        catalog = getToolByName(context, 'portal_catalog')
-        projectbrains = catalog.searchResults(portal_type='Project')
+        projectbrains = self.catalog.searchResults(portal_type='Project',
+                                                   review_state='active')
 
         if len(projectbrains) <= 1:
             # If there is maximal 1 project: return it...
@@ -38,46 +43,48 @@ class MyProjects(BrowserView):
             # Quick'n'Dirty check: pick the first project and check
             # whether the user has the customer role, but is not an
             # employee.
+            # ProjectManagers and Manager also get the entire list of active
+            # projects
             projectbrain = projectbrains[0]
             roles = member.getRolesInContext(projectbrain.getObject())
-            if 'Customer' in roles and 'Employee' not in roles:
+            if 'ProjectManager' in roles or 'Manager' in roles or \
+                'Customer' in roles and 'Employee' not in roles:
                 return projectbrains
 
             # Otherwise only show the projects with open tasks assigned to
             # this user.
             plist = []
+            states = ('open', 'to-do')
             for projectbrain in projectbrains:
                 searchpath = projectbrain.getPath()
-                taskbrains = catalog.searchResults(portal_type=['Task',
+                taskbrains = self.catalog.searchResults(portal_type=['Task',
                                                                 'PoiTask'],
                                                    getAssignees=memberid,
-                                                   review_state=self.states,
+                                                   review_state=states,
                                                    path=searchpath)
                 if len(taskbrains) > 0:
                     plist.append(projectbrain)
             return plist
 
 
-class ProjectAdminView(XMBaseView):
-    """Return management info about all projects.
-    Specifically: which iterations can be invoiced.
+class ProjectView(XMBaseView):
+    """Simply return info about a Project.
     """
 
     def projectlist(self):
         context = aq_inner(self.context)
         searchpath = '/'.join(context.getPhysicalPath())
         # Get a list of all projects
-        catalog = getToolByName(context, 'portal_catalog')
-        projectbrains = catalog.searchResults(portal_type='Project',
+        projectbrains = self.catalog.searchResults(portal_type='Project',
                                               path=searchpath)
 
         plist = []
         for projectbrain in projectbrains:
             searchpath = projectbrain.getPath()
             # Search for Iterations that are ready to get invoiced
-            iterationbrains = catalog.searchResults(portal_type='Iteration',
-                                                    review_state='completed',
-                                                    path=searchpath)
+            iterationbrains = self.catalog.searchResults(
+                portal_type='Iteration', review_state='completed',
+                path=searchpath)
             if len(iterationbrains) > 0:
                 iteration_list = []
                 for iterationbrain in iterationbrains:
@@ -91,9 +98,7 @@ class ProjectAdminView(XMBaseView):
     def iterationbrain2dict(self, brain):
         """Get a dict with info from this iteration brain.
         """
-        context = aq_inner(self.context)
         review_state_id = brain.review_state
-        workflow = getToolByName(context, 'portal_workflow')
         estimate = brain.estimate
         actual = brain.actual_time
         returnvalue = dict(
@@ -106,7 +111,7 @@ class ProjectAdminView(XMBaseView):
             actual = formatTime(actual),
             difference = formatTime(estimate - actual),
             review_state = review_state_id,
-            review_state_title = workflow.getTitleForStateOnType(
+            review_state_title = self.workflow.getTitleForStateOnType(
                                  review_state_id, 'Iteration'),
             brain= brain,
         )
@@ -115,7 +120,6 @@ class ProjectAdminView(XMBaseView):
     def projectbrain2dict(self, brain):
         """Get a dict with info from this project brain.
         """
-        context = aq_inner(self.context)
         returnvalue = dict(
             url = brain.getURL(),
             title = brain.Title,
@@ -124,15 +128,10 @@ class ProjectAdminView(XMBaseView):
         return returnvalue
 
 
-class ProjectView(ProjectAdminView):
-    """Simply return info about a Project.
-    """
-
     def main(self):
         """Get a dict with info from this context.
         """
         context = aq_inner(self.context)
-        workflow = getToolByName(context, 'portal_workflow')
         returnvalue = dict(
             title = context.Title(),
             description = context.Description(),
@@ -140,18 +139,10 @@ class ProjectView(ProjectAdminView):
             )
         return returnvalue
 
-    def finished_iterations(self):
-        states = ('completed', 'invoiced')
-        return self.getIterations(states)
-
     def current_iterations(self):
         states = ('in-progress', )
         return self.getIterations(states)
 
-    def open_iterations(self):
-        states = ('new', )
-        return self.getIterations(states)
-
     def getIterations(self, states=None):
         """Return the iterations, in catalog form
 
@@ -169,6 +160,17 @@ class ProjectView(ProjectAdminView):
             iteration_list.append(info)
         return iteration_list
 
+    def show_attachments(self):
+        """Should attachments be shown?
+
+        Not when there are no attachments and also not when xm.theme
+        is installed as the attachments can be seen in portlets then.
+        """
+        if HAS_XM_THEME:
+            return False
+        return len(self.attachments) != 0
+
+    @Lazy
     def attachments(self):
         """Return folder contents that are not iterations or offers
         """
@@ -180,8 +182,6 @@ class ProjectView(ProjectAdminView):
         all_brains = context.getFolderContents()
         brains = [brain for brain in all_brains
                   if brain.id not in iteration_ids]
-        if brains == []:
-            return None
         return brains
 
     def offers(self):
@@ -201,7 +201,4 @@ class ProjectView(ProjectAdminView):
                                     title = offer.Title,
                                     url = offer.getURL,
                                     icon = icon.html_tag()))
-        if results == []:
-            return None
-        else:
-            return results
+        return results
