@@ -65,10 +65,19 @@ class Story(OrderedBaseFolder):
 
     @property
     def size_estimate(self):
-        return self.getRoughEstimate()
+        "return the size estimate on a story in days"
+        if self.getRoughEstimate():
+            return self.getRoughEstimate()
+        else:
+            return 0.0
 
     security.declarePublic('recalc')
 
+    def set_size_estimate(self, val):
+        """Set the rough estimate and update the catalog"""
+        self.setRoughEstimate(val)
+        self.recalc()
+        
     def recalc(self):
         """See the ISizeEstimate interface.
         With our implementation we only need a reindex here actually.
